# FBP Calculator
FBP Calculator is a graphical tool for calculating Reaction System predictors.

## Installation
```
pip3 install fbp_calculator
```

After pip installing run the below:
```
python3 start.pyw
```

## License
This project is licensed under the [MIT License](https://github.com/deselmo/FBP-Calculator/blob/master/LICENSE).